server library

Functions

run(List<String> args, {List<DartDeskPlugin> plugins = const []}) → void
This is the starting point of your Serverpod server. In most cases, you will only need to make additions to this file if you add future calls, routes, or extensions that require setup at startup.